# aiXplain Pipelines 

aiXplain Pipelines enables python programmers to add AI functions
to their software.

## Installation

```
pip install aixplain-pipelines
```
### Developer Guide

#TODO(krishnadurai): Move to a separate document
```
pip install -e .
```

## Running Tests
### Setup environment

```
cp .env.example .env
```

Populate values in .env for pytest consumption.

### Run pytest

```
pytest
```